@@ -26,16 +26,20 @@ should be granted or not.
 from collections import defaultdict
 from . import roles, identity, predicates
 
-__all__ = ['ACL', 'Role', 'Permission']
+__all__ = ["ACL", "Role", "Permission"]
 
 
 class ACL(roles.RoleProvider):
 
-    environ_key = 'knave.acl'
+    environ_key = "knave.acl"
     environ = None
 
-    def __init__(self, role_providers, permissions_map,
-                 identity_adapter=identity.RemoteUserIdentityAdapter()):
+    def __init__(
+        self,
+        role_providers,
+        permissions_map,
+        identity_adapter=identity.RemoteUserIdentityAdapter(),
+    ):
 
         self._source_role_providers = []
         self._permission_roles = defaultdict(set)
@@ -54,8 +58,13 @@ class ACL(roles.RoleProvider):
             identity = self.identity_adapter(self.environ)
         return predicate(self, identity, context)
 
-    def require(self, predicate, context=None, identity=None,
-                exc=predicates.Unauthorized):
+    def require(
+        self,
+        predicate,
+        context=None,
+        identity=None,
+        exc=predicates.Unauthorized,
+    ):
         """
         Test a predicate, and raise Unauthorized if it is not met
         """
@@ -72,8 +81,9 @@ class ACL(roles.RoleProvider):
         bound_acl = ACL.__new__(ACL)
         bound_acl.__dict__ = self.__dict__.copy()
         bound_acl.environ = environ
-        bound_acl._role_provider = \
-                roles.CachingRoleProvider(self._role_provider, {})
+        bound_acl._role_provider = roles.CachingRoleProvider(
+            self._role_provider, {}
+        )
         environ[self.environ_key] = bound_acl
         return bound_acl
 
@@ -86,8 +96,7 @@ class ACL(roles.RoleProvider):
 
     def add_role_providers(self, role_providers):
         self._source_role_providers.extend(role_providers)
-        self._role_provider = \
-                make_role_provider(self._source_role_providers)
+        self._role_provider = make_role_provider(self._source_role_providers)
 
     def role_provider(self, provider_or_role, contextual=False):
         """
@@ -99,15 +108,18 @@ class ACL(roles.RoleProvider):
         returned that adds the decorated function using
         `func:~knave.roles.role_decider`.
         """
-        if isinstance(provider_or_role, type) and \
-                issubclass(provider_or_role, roles.RoleProvider):
+        if isinstance(provider_or_role, type) and issubclass(
+            provider_or_role, roles.RoleProvider
+        ):
             self.add_role_providers([provider_or_role()])
         elif isinstance(provider_or_role, roles.RoleProvider):
             self.add_role_providers([provider_or_role])
         else:
+
             def role_provider_decorator(fn):
                 provider = roles.role_decider(provider_or_role, contextual)(fn)
                 self.add_role_providers([provider])
+
             return role_provider_decorator
 
     def roles_for_permission(self, permission):
@@ -169,7 +181,7 @@ class Permission(predicates.Predicate):
         self.name = name
 
     def __repr__(self):
-        return '<Permission %r>' % (self.name,)
+        return "<Permission %r>" % (self.name,)
 
     def __call__(self, acl, identity, context=None):
         return acl.has_any(acl.roles_for_permission(self), identity, context)
@@ -190,7 +202,7 @@ class Role(predicates.Predicate):
         self.name = name
 
     def __repr__(self):
-        return '<Role %r>' % (self.name,)
+        return "<Role %r>" % (self.name,)
 
     def __call__(self, acl, identity, context):
         return acl.has_role(self, identity, context)
