@@ -12,8 +12,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-__all__ = ['IdentityAdapter', 'RepozeWhoIdentityAdapter',
-           'RemoteUserIdentityAdapter']
+__all__ = [
+    "IdentityAdapter",
+    "RepozeWhoIdentityAdapter",
+    "RemoteUserIdentityAdapter",
+]
 
 
 class IdentityAdapter(object):
@@ -32,11 +35,10 @@ class IdentityAdapter(object):
 
 
 class RepozeWhoIdentityAdapter(IdentityAdapter):
-
     def __call__(self, environ):
-        identity = environ.get('repoze.who.identity')
+        identity = environ.get("repoze.who.identity")
         if identity is not None:
-            return identity['repoze.who.userid']
+            return identity["repoze.who.userid"]
         return None
 
 
@@ -44,5 +46,6 @@ class RemoteUserIdentityAdapter(IdentityAdapter):
     """
     Look for the identity in `environ['REMOTE_USER']`
     """
+
     def __call__(self, environ):
-        return environ.get('REMOTE_USER')
+        return environ.get("REMOTE_USER")
