@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-__all__ = ['Unauthorized', 'Predicate', 'make_predicate', 'Not', 'Any', 'All']
+__all__ = ["Unauthorized", "Predicate", "make_predicate", "Not", "Any", "All"]
 
 
 class Unauthorized(Exception):
@@ -25,7 +25,6 @@ class Unauthorized(Exception):
 
 
 class Predicate(object):
-
     def __call__(self, acl, identity, context=None):
         """
         Return the result of evaluating the predicate in the WSGI request
@@ -48,14 +47,15 @@ def make_predicate(func):
                  ``(acl, identity, context)`` and returns a boolean.
     :return: a :class:`knave.predicates.Predicate` instance
     """
+
     class FunctionPredicate(Predicate):
         def __call__(self, acl, identity, context=None):
             return func(acl, identity, context)
+
     return FunctionPredicate()
 
 
 class Not(Predicate):
-
     def __init__(self, other):
         self.predicate = other
 
@@ -74,8 +74,9 @@ class CompoundPredicate(Predicate):
         self.predicates = predicates
 
     def __call__(self, acl, identity, context=None):
-        return self.aggregate_func(p(acl, identity, context)
-                                   for p in self.predicates)
+        return self.aggregate_func(
+            p(acl, identity, context) for p in self.predicates
+        )
 
 
 class All(CompoundPredicate):
